##  Activating Data Quality Insights
Admin users can activate the feature in the admin area. To activate, do the following:
  1. Navigate to the Optional Features and Early Access section of the administration area.
  2. Click Activate next to Data Quality Insights in Inventory.
![Activating Data Quality Insights](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loiob157eb317abe4fd2a1cea81793071f06_LowRes.png)
Activating Data Quality Insights


Similarly, you can deactivate it at any time by clicking Deactivate.
